@@ -33,9 +33,10 @@
 #  define DIFF2_DEPRECATED_NO_EXPORT DIFF2_NO_EXPORT DIFF2_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define DIFF2_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef DIFF2_NO_DEPRECATED
+#    define DIFF2_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
